@@ -1,7 +1,7 @@
 package Langertha::Engine::OpenAI;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: OpenAI API
-$Langertha::Engine::OpenAI::VERSION = '0.003';
+$Langertha::Engine::OpenAI::VERSION = '0.004';
 use Moose;
 use File::ShareDir::ProjectDistDir qw( :all );
 use Carp qw( croak );
@@ -13,6 +13,7 @@ with 'Langertha::Role::'.$_ for (qw(
   OpenAPI
   Models
   Temperature
+  ResponseSize
   SystemPrompt
   Chat
   Embedding
@@ -76,6 +77,7 @@ sub chat_request {
   return $self->generate_request( createChatCompletion => sub { $self->chat_response(shift) },
     model => $self->chat_model,
     messages => $messages,
+    $self->get_response_size ? ( max_tokens => $self->get_response_size ) : (),
     $self->has_temperature ? ( temperature => $self->temperature ) : (),
     stream => JSON->false,
     # $self->has_seed ? ( seed => $self->seed )
@@ -121,7 +123,7 @@ Langertha::Engine::OpenAI - OpenAI API
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
